import { WorkflowSteps } from 'projen/lib/github';
import { JobStep, JobStepConfiguration } from 'projen/lib/github/workflows-model';
export declare class SnykWorkflowSteps extends WorkflowSteps {
    static setupNode(options?: SetupNodeOptions): JobStep[];
    static getNpmRoot(options?: JobStepConfiguration): JobStep[];
    static createCache(options: CreateCacheOptions): JobStep[];
    static installSnyk(options: InstallSnykOptions): JobStep[];
    static installSnykPrDiff(options: InstallSnykPrDiffOptions): JobStep[];
    static authenticateSnyk(options: AuthenticateSnykOptions): JobStep[];
    static runSca(options?: RunScaOptions): JobStep[];
    static runSnykScaWithDelta(options: RunSnykScaWithDeltaOptions): JobStep[];
    static runSnykSast(options: RunSnykSastOptions): JobStep[];
    static runSnykPrDiff(options: RunSnykPrDiffOptions): JobStep[];
    private static multiLineCommands;
}
export interface SetupNodeOptions extends JobStepConfiguration {
    readonly nodeVersion?: number;
}
export interface CreateCacheOptions extends JobStepConfiguration {
    readonly with: CreateCacheWithOptions;
}
export interface CreateCacheWithOptions {
    readonly path: string;
    readonly key: string;
    readonly restoreKeys?: string;
    readonly uploadChunkSize?: string;
    readonly enableCrossOsArchive?: boolean;
    readonly failOnCacheMiss?: boolean;
    readonly lookupOnly?: boolean;
    readonly saveAlways?: boolean;
}
export interface InstallSnykOptions extends JobStepConfiguration {
    readonly cache?: boolean;
    readonly snykVersion?: string;
    readonly snykDeltaVersion?: string;
    readonly createCacheOptions?: CreateCacheOptions;
}
export interface InstallSnykPrDiffOptions extends JobStepConfiguration {
    readonly cache?: boolean;
    readonly version?: string;
    readonly createCacheOptions?: CreateCacheOptions;
}
export interface AuthenticateSnykOptions extends JobStepConfiguration {
    readonly snykOrgId: string;
    readonly snykToken?: string;
}
export interface RunScaOptions extends JobStepConfiguration {
    readonly severityThreshold?: string;
    readonly resultPathOutputId?: string;
    readonly args?: string;
}
export interface RunSnykScaWithDeltaOptions extends JobStepConfiguration {
    readonly authenticateSnykOptions: AuthenticateSnykOptions;
    readonly snykMonitoredProjectId: string;
    readonly severityThreshold?: string;
    readonly delta?: boolean;
    readonly debug?: boolean;
    readonly runScaOptions?: RunScaOptions;
}
export interface RunSnykSastOptions extends JobStepConfiguration {
    readonly authenticateSnykOptions: AuthenticateSnykOptions;
    readonly severityThreshold?: string;
}
export interface RunSnykPrDiffOptions extends JobStepConfiguration {
    readonly snykCodeBaselinePath: string;
    readonly snykCodeCurrentPath: string;
}
